---
Summary: `svalid` program
Status: Done
---

# Description

`svalid` is intended for use in scripts (such as commit hooks) to check the repository is valid.

When it's called:

-   Return error code 0 if everything is OK.
-   Return error code 1 if there is another error
-   Return error code 2 if there are any invalid files (such as invalid md or no `summary`).
-   Return error code 3 if there is a breach in a rule - such as a field that is not permitted, or a reference to a card that doesn't exist.
